@@ -7,9 +7,9 @@ from mock import Mock, patch
 import vessl
 from openapi_client.api.api_v1_api import APIV1Api
 from openapi_client.models import (
-    SignInAPIPayload,
-    SignInCliConfirmAPIPayload,
-    SignUpAPIPayload,
+    SignInAPIInput,
+    SignInCliConfirmAPIInput,
+    SignUpAPIInput,
 )
 from vessl.util.config import VesslConfigLoader
 from vessl.util.exception import VesslApiException
@@ -17,6 +17,10 @@ from vessl.util.exception import VesslApiException
 USE_MOCK = not os.environ.get("VESSL_TEST_MOCK_OFF", False)
 TEST_CONFIG_PATH = "test/config"
 
+TEST_CLUSTER_NAME = "aws-uw2-dev"
+TEST_IMAGE_NAME = "vessl/kernels:py36.full-cpu"
+TEST_RESOURCE_NAME = "v1.cpu-0.mem-1"
+
 vessl.EXEC_MODE = "TEST"
 
 
@@ -69,14 +73,14 @@ def setup_test_account():
     # Setup user
     try:
         jwt_token = vessl.vessl_api.sign_in_api(
-            sign_in_api_payload=SignInAPIPayload(
+            sign_in_api_input=SignInAPIInput(
                 email_or_username=email,
                 password=password,
             )
         ).token
     except VesslApiException:
         jwt_token = vessl.vessl_api.sign_up_api(
-            sign_up_api_payload=SignUpAPIPayload(
+            sign_up_api_input=SignUpAPIInput(
                 name=name,
                 username=username,
                 password=password,
@@ -92,7 +96,7 @@ def setup_test_account():
         f"JWT {jwt_token}",
     )
     vessl.vessl_api.sign_in_cli_confirm_api(
-        sign_in_cli_confirm_api_payload=SignInCliConfirmAPIPayload(
+        sign_in_cli_confirm_api_input=SignInCliConfirmAPIInput(
             cli_token=cli_token,
         )
     )
