@@ -1,11 +1,11 @@
 import shutil
 from test.conftest import USE_MOCK
-from test.util import random_string
 
 import pytest
 
 import vessl
 from vessl.util.exception import VesslApiException
+from vessl.util.random import random_string
 
 
 @pytest.mark.skipif(USE_MOCK, reason="Does not run if mocking is used.")
@@ -22,7 +22,6 @@ class TestDataset:
             dataset_name=self.dataset_name,
             description=random_string(),
         )
-        # TODO: test s3 and gs datasets
 
     @pytest.mark.order(index=2)
     def test_upload_dataset_volume_file(self):
