@@ -14,18 +14,17 @@ from click.decorators import pass_context
 from sentry_sdk.integrations.logging import ignore_logger
 
 import vessl
+from vessl._version import __VERSION__
 from vessl.cli._base import VesslGroup
 from vessl.cli._util import prompt_choices
 from vessl.cli.dataset import cli as dataset_cli
-from vessl.cli.experiment import (
-    cli as experiment_cli,
-    create as experiment_create,
-    logs as experiment_logs,
-)
+from vessl.cli.experiment import cli as experiment_cli
+from vessl.cli.experiment import create as experiment_create
+from vessl.cli.experiment import logs as experiment_logs
 from vessl.cli.kernel_cluster import cli as kernel_cluster_cli
 from vessl.cli.kernel_image import cli as kernel_image_cli
 from vessl.cli.kernel_resource_spec import cli as kernel_resource_spec_cli
-from vessl.cli.model import cli as model_cli
+from vessl.cli.model import model_cli, model_repository_cli
 from vessl.cli.organization import cli as organization_cli
 from vessl.cli.project import cli as project_cli
 from vessl.cli.ssh_key import cli as ssh_key_cli
@@ -33,6 +32,7 @@ from vessl.cli.sweep import cli as sweep_cli
 from vessl.cli.volume import cli as volume_cli
 from vessl.cli.workspace import cli as workspace_cli
 from vessl.util.config import DEFAULT_CONFIG_PATH, VesslConfigLoader
+from vessl.util.constant import API_HOST
 from vessl.util.exception import (
     InvalidOrganizationError,
     InvalidProjectError,
@@ -40,12 +40,18 @@ from vessl.util.exception import (
     VesslApiException,
 )
 
-# Configure Sentry
-sentry_sdk.init(
-    os.environ.get("SENTRY_DSN", "https://e46fcd750b3a443fbd5b9dbc970e4ecf@o386227.ingest.sentry.io/5911639"),
-    traces_sample_rate=1.0,
-)
-ignore_logger("vessl_logger")
+# Configure Sentry in production
+if API_HOST == "https://api.vessl.ai":
+    sentry_sdk.init(
+        os.environ.get(
+            "SENTRY_DSN",
+            "https://e46fcd750b3a443fbd5b9dbc970e4ecf@o386227.ingest.sentry.io/5911639",
+        ),
+        traces_sample_rate=1.0,
+        ignore_errors=[VesslApiException],
+    )
+    sentry_sdk.set_tag("cli_version", __VERSION__)
+    ignore_logger("vessl.util.logger")
 
 
 def prompt_organizations() -> str:
@@ -125,26 +131,6 @@ def configure(
     print(f"Welcome, {vessl.vessl_api.user.display_name}!")
 
 
-@configure.vessl_command(hidden=True)
-@click.pass_context
-@click.argument("extras", nargs=-1)
-def run(ctx, extras: List[str]):
-    args = []
-    args.extend(["--command", ' '.join(extras)])
-    args.extend(["--upload-local-git-diff", "false"])
-    args.extend(["--working-dir", "/home/vessl/local/"])
-    args.extend(["--upload-local-file", ".:/home/vessl/local/"])
-
-    ctx.params = {}
-    ctx.args = experiment_create.parse_args(ctx, args)
-    ctx.forward(experiment_create)
-
-    experiment = ctx.obj.get("experiment")
-    ctx.params = {}
-    ctx.args = experiment_logs.parse_args(ctx, [experiment.name, "--follow"])
-    ctx.forward(experiment_logs)
-
-
 @configure.vessl_command()
 @click.argument("organization", type=click.STRING, required=False)
 def organization(organization: str):
@@ -198,19 +184,38 @@ def list():
     )
 
 
+@cli.vessl_command()
+@click.pass_context
+@click.argument("command", nargs=-1, required=True)
+def run(ctx, command: List[str]):
+    args = []
+    args.extend(["--command", " ".join(command)])
+    args.extend(["--working-dir", "/home/vessl/local/"])
+    args.extend(["--upload-local-file", ".:/home/vessl/local/"])
+
+    ctx.params = {}
+    ctx.args = experiment_create.parse_args(ctx, args)
+    ctx.forward(experiment_create)
+
+    experiment_number = ctx.obj.get("experiment_number")
+    ctx.params = {}
+    ctx.args = experiment_logs.parse_args(ctx, [experiment_number, "--follow"])
+    ctx.forward(experiment_logs)
+
+
 cli.add_command(dataset_cli)
 cli.add_command(experiment_cli)
 cli.add_command(kernel_cluster_cli)
 cli.add_command(kernel_image_cli)
 cli.add_command(kernel_resource_spec_cli)
 cli.add_command(model_cli)
+cli.add_command(model_repository_cli)
 cli.add_command(organization_cli)
 cli.add_command(project_cli)
 cli.add_command(ssh_key_cli)
 cli.add_command(sweep_cli)
 cli.add_command(volume_cli)
 cli.add_command(workspace_cli)
-cli.add_command(run)
 
 
 if __name__ == "__main__":
