@@ -20,6 +20,8 @@ class Endpoint:
     experiment_logs = (
         WEB_HOST + "/{}/{}/experiments/{}/logs"
     )  # Organization name, project name, experiment number
+    model_repository = WEB_HOST + "/{}/models/{}"  # Organization name, repository name
+    model = WEB_HOST + "/{}/models/{}/{}"  # Organization name, repository name, number
     organization = WEB_HOST + "/{}"  # Organization name
     project = WEB_HOST + "/{}/{}"  # Organization name, project name
     sweep = WEB_HOST + "/{}/{}/sweeps/{}"  # Organization name, project name, sweep name
@@ -81,7 +83,7 @@ def print_data(data: Dict[str, Any]) -> None:
 def print_logs(logs: List[Any]):
     timezone = datetime.now().astimezone().tzinfo
     for log in logs:
-        ts = datetime.fromtimestamp(log.timestamp, tz=timezone).strftime('%H:%M:%S.%f')
+        ts = datetime.fromtimestamp(log.timestamp, tz=timezone).strftime("%H:%M:%S.%f")
         message = log.message.replace("\\r", "\n").replace("\\n", "\n")
         for x in message.split("\n"):
             print(f"[{ts}] {x}")
@@ -116,6 +118,14 @@ def format_string(value: str, null_value: str = "None", empty_value: str = "-")
     return value
 
 
+def format_url(url: str) -> str:
+    """Prints in url format
+
+    Replace whitespaces with %20. More url rules could be added.
+    """
+    return url.replace(" ", "%20")
+
+
 def print_volume_files(
     files: List[ResponseFileMetadata],
     keys: List[str] = None,
@@ -154,6 +164,12 @@ def prompt_choices(text: str, choices: List[Any], default: Any = None) -> Any:
     return inquirer.prompt([inquiry], raise_keyboard_interrupt=True).get(key)
 
 
+def prompt_checkbox(text: str, choices: List[Any], default: Any = None) -> Any:
+    key = "question"
+    inquiry = inquirer.Checkbox(key, message=text, default=default, choices=choices)
+    return inquirer.prompt([inquiry], raise_keyboard_interrupt=True).get(key)
+
+
 def generic_prompter(
     text: str, type: click.ParamType = click.STRING, default=None
 ) -> Callable:
@@ -168,3 +184,11 @@ def choices_prompter(text: str, choices: List[Any], default: Any = None) -> Call
         return prompt_choices(text, choices, default)
 
     return prompter
+
+
+def sizeof_fmt(num, suffix="B"):
+    for unit in ["", "Ki", "Mi", "Gi", "Ti", "Pi", "Ei", "Zi"]:
+        if abs(num) < 1024.0:
+            return f"{num:3.1f}{unit}{suffix}"
+        num /= 1024.0
+    return f"{num:.1f}Yi{suffix}"
\ No newline at end of file
