@@ -99,6 +99,12 @@ def list():
     "name", type=click.STRING, required=True, prompter=generic_prompter("Dataset name")
 )
 @click.option("-m", "--description", type=click.STRING)
+@click.option(
+    "--is-public",
+    type=click.BOOL,
+    is_flag=True,
+    help="Required if dataset sourced from a public bucket.",
+)
 @click.option(
     "-e",
     "--external-path",
@@ -116,6 +122,7 @@ def list():
 def create(
     name: str,
     description: str,
+    is_public: bool,
     external_path: str,
     aws_role_arn: str,
     enable_versioning: bool,
@@ -125,12 +132,13 @@ def create(
         dataset_name=name,
         description=description,
         is_version_enabled=enable_versioning,
+        is_public=is_public,
         external_path=external_path,
         aws_role_arn=aws_role_arn,
         version_path=version_path,
     )
     print(
-        f"Created '{dataset.name}'."
+        f"Created '{dataset.name}'.\n"
         f"For more info: {Endpoint.dataset.format(dataset.organization.name, dataset.name)}"
     )
 
