@@ -10,11 +10,11 @@ from typing import Any, Dict, List, Optional, Union
 from urllib3.exceptions import MaxRetryError
 
 from openapi_client.models.experiment_metric_entry import ExperimentMetricEntry
-from openapi_client.models.experiment_metrics_update_api_payload import (
-    ExperimentMetricsUpdateAPIPayload,
+from openapi_client.models.experiment_metrics_update_api_input import (
+    ExperimentMetricsUpdateAPIInput,
 )
-from openapi_client.models.local_experiment_finish_api_payload import (
-    LocalExperimentFinishAPIPayload,
+from openapi_client.models.local_experiment_finish_api_input import (
+    LocalExperimentFinishAPIInput,
 )
 from openapi_client.models.response_experiment_info import ResponseExperimentInfo
 from vessl.cli._util import Endpoint
@@ -91,7 +91,7 @@ class Sender(object):
         try:
             res = self._api.experiment_metrics_update_api(
                 self._experiment_id,
-                experiment_metrics_update_api_payload=ExperimentMetricsUpdateAPIPayload(
+                experiment_metrics_update_api_input=ExperimentMetricsUpdateAPIInput(
                     metrics=payload
                 ),
             )
@@ -159,7 +159,7 @@ class VesslRun(object):
 
     def _get_experiment_from_args(
         self,
-        experiment_name_or_number,
+        experiment_number,
         message: str = None,
         hyperparameters: Hyperparameters = None,
     ) -> ResponseExperimentInfo:
@@ -168,24 +168,26 @@ class VesslRun(object):
         If experiment is specified, use it. Otherwise, create a new experiment.
         """
         # Create a new experiment
-        if experiment_name_or_number is None:
+        if experiment_number is None:
             from vessl.experiment import create_local_experiment
 
-            experiment = create_local_experiment(message=message, hyperparameters=hyperparameters)
+            experiment = create_local_experiment(
+                message=message, hyperparameters=hyperparameters
+            )
             logger.debug(f"Created experiment {experiment.id}")
             return experiment
 
         # Continue with previous experiment
         from vessl.experiment import read_experiment
 
-        experiment = read_experiment(experiment_name_or_number)
+        experiment = read_experiment(experiment_number)
         if not experiment.is_local or experiment.local_execution_spec is None:
             raise InvalidExperimentError(
-                f"{experiment.name}: cannot use Vessl-managed experiment."
+                f"{experiment.number}: cannot use Vessl-managed experiment."
             )
         if experiment.status != "running":
             raise InvalidExperimentError(
-                f"{experiment.name}: experiment must be running."
+                f"{experiment.number}: experiment must be running."
             )
 
         return experiment
@@ -212,7 +214,7 @@ class VesslRun(object):
         sys.exit = self._exit_hook.orig_exit
         self.api.local_experiment_finish_api(
             self._experiment.id,
-            local_experiment_finish_api_payload=LocalExperimentFinishAPIPayload(
+            local_experiment_finish_api_input=LocalExperimentFinishAPIInput(
                 exit_code=self._exit_hook.exit_code
             ),
         )
@@ -225,7 +227,7 @@ class VesslRun(object):
         assert self._mode == MODE_MANAGED
         res = self.api.experiment_metrics_update_api(
             self._experiment.id,
-            experiment_metrics_update_api_payload=ExperimentMetricsUpdateAPIPayload(
+            experiment_metrics_update_api_input=ExperimentMetricsUpdateAPIInput(
                 metrics=payloads
             ),
         )
@@ -234,7 +236,7 @@ class VesslRun(object):
 
     def init(
         self,
-        experiment_name_or_number=None,
+        experiment_number=None,
         message: str = None,
         tensorboard: bool = False,
         hp: dict = None,
@@ -246,7 +248,7 @@ class VesslRun(object):
         this will do nothing.
 
         Args:
-            experiment_name_or_number (str | int): experiment name or number
+            experiment_number (str | int): experiment name or number
             message (str): experiment message
             tensorboard (bool): enable tensorboard integration. It is important to note
               that `vessl.init` must be called **before** initializing the writer
@@ -255,13 +257,16 @@ class VesslRun(object):
         """
         if self._mode == MODE_NOT_STARTED:
             print(f"Initializing a new experiment...")
-            self.api.configure()
+            self.api.set_configurations(
+                organization_name=kwargs.get("organization_name"),
+                project_name=kwargs.get("project_name"),
+            )
 
             if hp:
                 self.hyperparameters.update_items(hp)
 
             self._experiment = self._get_experiment_from_args(
-                experiment_name_or_number,
+                experiment_number,
                 message,
                 self.hyperparameters.as_list_of_dict(),
             )
@@ -269,7 +274,7 @@ class VesslRun(object):
             self.hyperparameters.configure(self.api, self._experiment)
 
             print(
-                f"Connected to {self._experiment.name}.\n"
+                f"Connected to {self._experiment.number}.\n"
                 f"For more info: {Endpoint.experiment.format(self._experiment.organization.name, self._experiment.project.name, self._experiment.number)}"
             )
 
@@ -293,7 +298,7 @@ class VesslRun(object):
             self.hyperparameters.update(hp)
 
         if tensorboard:
-            self._tensorboard_collector = integrate_tensorboard()
+            integrate_tensorboard()
 
     def upload(self, path: str):
         """Upload output files
@@ -307,7 +312,7 @@ class VesslRun(object):
 
         from vessl.experiment import upload_experiment_output_files
 
-        upload_experiment_output_files(self._experiment.name, path)
+        upload_experiment_output_files(self._experiment.number, path)
 
     def finish(self):
         """Teardown Vessl settings
@@ -326,10 +331,10 @@ class VesslRun(object):
             return
 
         self._stop()
-        experiment_name = self._experiment.name
+        experiment_number = self._experiment.number
         self._mode = MODE_NOT_STARTED
         self._experiment = None
-        print(f"Experiment {experiment_name} completed.")
+        print(f"Experiment {experiment_number} completed.")
 
     def log(
         self,
