@@ -1,7 +1,7 @@
 from typing import List
 
 from openapi_client.models import (
-    OrganizationCreateAPIPayload,
+    OrganizationCreateAPIInput,
     ResponseOrganization,
     ResponseOrganizationInfo,
 )
@@ -10,18 +10,51 @@ from vessl.util.exception import InvalidOrganizationError
 
 
 def read_organization(organization_name: str) -> ResponseOrganizationInfo:
+    """Read organization
+
+    Args:
+        organization_name(str): Organization name.
+
+    Example:
+        ```python
+        vessl.read_organization(
+            organization_name="foo"
+        )
+        ```
+    """
     return vessl_api.organization_read_api(organization_name=organization_name)
 
 
 def list_organizations() -> List[ResponseOrganization]:
+    """List organizations
+
+    Example:
+        ```python
+        vessl.list_organizations()
+        ```
+    """
     return vessl_api.organization_list_api().organizations
 
 
 def create_organization(
     organization_name: str, region: str
 ) -> ResponseOrganizationInfo:
+    """Create oragnization
+
+    Args:
+        organization_name(str): Organization name.
+        region(str): Physical location where your cluster data centers.
+
+    Example:
+        ```python
+        vessl.create_organization(
+            organization_name="foo",
+            region="ap-northeast-2",
+        )
+        ```
+    """
     return vessl_api.organization_create_api(
-        organization_create_api_payload=OrganizationCreateAPIPayload(
+        organization_create_api_input=OrganizationCreateAPIInput(
             name=organization_name, region=region
         )
     )
