@@ -44,7 +44,7 @@ SWEEP_OBJECTIVE_TYPES = [SWEEP_OBJECTIVE_TYPE_MAXIMIZE, SWEEP_OBJECTIVE_TYPE_MIN
 
 SWEEP_ALGORITHM_TYPE_GRID = "grid"
 SWEEP_ALGORITHM_TYPE_RANDOM = "random"
-SWEEP_ALGORITHM_TYPE_BAYESIAN = "baysian"
+SWEEP_ALGORITHM_TYPE_BAYESIAN = "bayesian"
 SWEEP_ALGORITHM_TYPES = [
     SWEEP_ALGORITHM_TYPE_GRID,
     SWEEP_ALGORITHM_TYPE_RANDOM,
@@ -67,10 +67,14 @@ SWEEP_PARAMETER_RANGE_TYPES = [
     SWEEP_PARAMETER_RANGE_TYPE_LIST,
 ]
 
+MODEL_SOURCE_EXPERIMENT = "experiment"
+MODEL_SOURCE_LOCAL = "local"
+
 MOUNT_TYPE_CODE = "code"
 MOUNT_TYPE_ARCHIVE_FILE = "archive-file"
 MOUNT_TYPE_DATASET = "dataset"
 MOUNT_TYPE_DATASET_VERSION = "dataset-version"
+MOUNT_TYPE_MODEL_VOLUME = "model-volume"
 MOUNT_TYPE_EMPTY_DIR = "empty-dir"
 MOUNT_TYPE_OUTPUT = "output"
 MOUNT_TYPE_PROJECT = "project"
