@@ -1,7 +1,8 @@
 import os
 import tempfile
-from typing import List, Optional
+from typing import Dict, List, Optional
 
+from openapi_client import ProtoVolumeMountRequestSourceModelVolume
 from openapi_client.models import (
     ProtoVolumeMountRequest,
     ProtoVolumeMountRequests,
@@ -10,8 +11,8 @@ from openapi_client.models import (
     ProtoVolumeMountRequestSourceDataset,
     ProtoVolumeMountRequestSourceDatasetVersion,
     ResponseFileMetadata,
-    VolumeFileCopyAPIPayload,
-    VolumeFileCreateAPIPayload,
+    VolumeFileCopyAPIInput,
+    VolumeFileCreateAPIInput,
 )
 from vessl import vessl_api
 from vessl.organization import _get_organization_name
@@ -24,17 +25,37 @@ from vessl.util.constant import (
     MOUNT_TYPE_DATASET,
     MOUNT_TYPE_DATASET_VERSION,
     MOUNT_TYPE_EMPTY_DIR,
+    MOUNT_TYPE_MODEL_VOLUME,
     MOUNT_TYPE_OUTPUT,
 )
 from vessl.util.downloader import Downloader
-from vessl.util.exception import GitError, InvalidVolumeFileError, VesslApiException
-from vessl.util.git import get_git_diff_path, get_git_ref, get_git_repo
+from vessl.util.exception import (
+    GitError,
+    InvalidParamsError,
+    InvalidVolumeFileError,
+    VesslApiException,
+)
+from vessl.util.git_local import get_git_diff_path, get_git_ref, get_git_repo
 from vessl.util.random import random_string
 from vessl.util.uploader import Uploader
 from vessl.util.zipper import Zipper
 
 
 def read_volume_file(volume_id: int, path: str) -> ResponseFileMetadata:
+    """Read a file in the volume.
+
+    Args:
+        volume_id(int): Volume ID.
+        path(str): Path within the volume.
+
+    Example:
+        ```python
+        vessl.read_volume_file(
+            volume_id=123456,
+            path="train.csv",
+        )
+        ```
+    """
     return vessl_api.volume_file_read_api(volume_id=volume_id, path=path)
 
 
@@ -44,6 +65,23 @@ def list_volume_files(
     path: str = "",
     recursive: bool = False,
 ) -> List[ResponseFileMetadata]:
+    """List files in the volume.
+
+    Args:
+        volume_id(int): Volume ID.
+        need_download_url(bool): True if you need a download URL, False
+            otherwise. Defaults to False.
+        path(str): Path within the volume. Defaults to root.
+        recursive(bool): True if list files recursively, False otherwise.
+            Defaults to False.
+
+    Example:
+        ```python
+        vessl.list_volume_files(
+            volume_id=123456,
+        )
+        ```
+    """
     result = vessl_api.volume_file_list_api(
         volume_id=volume_id,
         recursive=recursive,
@@ -54,9 +92,25 @@ def list_volume_files(
 
 
 def create_volume_file(volume_id: int, is_dir: bool, path: str) -> ResponseFileMetadata:
+    """Create file in the volume.
+
+    Args:
+        volume_id(int): Volume ID.
+        is_dir(bool): True if a file is directory, False otherwise.
+        path(str): Path within the volume.
+
+    Example:
+        ```python
+        vessl.create_volume_file(
+            volume_id=123456,
+            is_dir=False,
+            path="models"
+        )
+        ```
+    """
     result = vessl_api.volume_file_create_api(
         volume_id=volume_id,
-        volume_file_create_api_payload=VolumeFileCreateAPIPayload(
+        volume_file_create_api_input=VolumeFileCreateAPIInput(
             is_dir=is_dir,
             path=path,
         ),
@@ -68,12 +122,42 @@ def create_volume_file(volume_id: int, is_dir: bool, path: str) -> ResponseFileM
 def delete_volume_file(
     volume_id: int, path: str, recursive: bool = False
 ) -> List[ResponseFileMetadata]:
+    """Delete file in the volume.
+
+    Args:
+        volume_id(int): Volume ID.
+        path(str): Path within the volume.
+        recursive(bool): True if list files recursively, False otherwise.
+            Defaults to False.
+
+    Example:
+        ```python
+        vessl.delete_volume_file(
+            volume_id=123456,
+            path="model.pth",
+        )
+        ```
+    """
     return vessl_api.volume_file_delete_api(
         volume_id=volume_id, path=path, recursive=recursive
     ).deleted_files
 
 
 def upload_volume_file(volume_id: int, path: str) -> ResponseFileMetadata:
+    """Upload file in the volume.
+
+    Args:
+        volume_id(int): Volume ID.
+        path(str): Local file path to upload
+
+    Example:
+        ```python
+        vessl.upload_volume_file(
+            volume_id=123456,
+            path="model.pth",
+        )
+        ```
+    """
     return vessl_api.volume_file_uploaded_api(volume_id=volume_id, path=path)
 
 
@@ -82,8 +166,36 @@ def copy_volume_file(
     source_path: str,
     dest_volume_id: Optional[int],
     dest_path: str,
-    recursive: bool = False,
+    recursive: bool = False,  # Only used for remote to remote
+    quiet: bool = False,
 ) -> Optional[List[ResponseFileMetadata]]:
+    """Copy file either from local to remote, remote to local, or remote to
+    remote.
+
+    Args:
+        source_volume_id(Optional[int]): Source volume file id. If not
+            specified, source is assumed to be local.
+        source_path(str): If source_volume_id is empty, local source path.
+            Otherwise, remote source path.
+        dest_volume_id(Optional[int]): Destination volume file id. If not
+            specified, destination is assumed to be local.
+        dest_path(str): If dest_volume_id is empty, local destination path.
+            Otherwise, remote destination path.
+        recursive(bool): True if list files recursively, False otherwise.
+            Only used for remote to remote copy. Defaults to False.
+        quiet(bool): True if the muted output, False otherwise. Defaults to
+            False.
+
+    Example:
+        ```python
+        vessl.copy_volume_file(
+            source_volume_id=123456,
+            source_path="model.pth",
+            dest_volume_id=123457,
+            dest_path="model.pth",
+        )
+        ```
+    """
     if source_volume_id is None and dest_volume_id:
         return _copy_volume_file_local_to_remote(
             source_path,
@@ -96,6 +208,7 @@ def copy_volume_file(
             source_volume_id,
             source_path,
             dest_path,
+            quiet,
         )
 
     if source_volume_id and dest_volume_id:
@@ -155,6 +268,7 @@ def _copy_volume_file_remote_to_local(
     source_volume_id: int,
     source_path: str,
     dest_path: str,
+    quiet: bool = False,
 ) -> None:
     """Copy remote to local
 
@@ -164,22 +278,34 @@ def _copy_volume_file_remote_to_local(
       - `dest_path` is directory: copy file into directory with original name
     - `source_path` is directory
       - `dest_path` is file: error
-      - `dest_path` does not exist: create `dest_path` and copy contents of `source_path`
+      - `dest_path` does not exist: create `dest_path` and copy contents of `source_path` (like cp -r)
       - `dest_path` exists: copy `source_path` as subdirectory of `dest_path`
     """
 
-    output = "Successfully downloaded {} out of {} file(s)."
     source_file = read_volume_file(source_volume_id, source_path)
 
     if not source_file.is_dir:
+        file_name = os.path.basename(source_file.path)
         if os.path.isdir(dest_path):
-            dest_path = os.path.join(dest_path, os.path.basename(source_file.path))
+            dest_path = os.path.join(dest_path, file_name)
 
-        Downloader.download(dest_path, source_file)
+            if os.path.isdir(dest_path):
+                # Case where `source_path` is "a.txt", `dest_path` is "dir/", and
+                # "dir/a.txt/" exists as a directory
+                raise InvalidParamsError(
+                    f"Cannot overwrite directory {dest_path} with non-directory {file_name}."
+                )
 
-        print(output.format(1, 1))
+        Downloader.download(source_path, dest_path, source_file, quiet=quiet)
         return
 
+    if os.path.isfile(dest_path):
+        # Case where `source_path` is a directory and `dest_path` is an
+        # existing filename
+        raise InvalidVolumeFileError(
+            f"Destination path is not a directory: {dest_path}."
+        )
+
     files = list_volume_files(
         volume_id=source_volume_id,
         need_download_url=True,
@@ -187,23 +313,7 @@ def _copy_volume_file_remote_to_local(
         recursive=True,
     )
 
-    if os.path.isfile(dest_path):
-        raise InvalidVolumeFileError(
-            f"Destination path is not a directory: {dest_path}."
-        )
-
-    prefix = source_path.rstrip("/")
-    if os.path.isdir(dest_path):
-        prefix = os.path.dirname(prefix)
-
-    if prefix:
-        prefix += "/"
-        for file in files:
-            file.path = file.path.replace(prefix, "", 1)  # Remove prefix
-            file.path = os.path.normpath(file.path)
-
-    downloaded_files = Downloader.bulk_download(dest_path, files)
-    print(output.format(len(downloaded_files), len([x for x in files if not x.is_dir])))
+    Downloader.download(source_path, dest_path, *files, quiet=quiet)
 
 
 def _copy_volume_file_remote_to_remote(
@@ -218,7 +328,7 @@ def _copy_volume_file_remote_to_remote(
 
     files = vessl_api.volume_file_copy_api(
         volume_id=source_volume_id,
-        volume_file_copy_api_payload=VolumeFileCopyAPIPayload(
+        volume_file_copy_api_input=VolumeFileCopyAPIInput(
             dest_path=dest_path,
             recursive=recursive,
             source_dataset_version="latest",
@@ -226,19 +336,45 @@ def _copy_volume_file_remote_to_remote(
         ),
     ).copied_files
 
-    print(f"Successfully downloaded {len(files)} out of {len(files)} file(s).")
+    print(f"Successfully copied {len(files)} out of {len(files)} file(s).")
+
+
+def _print_volume_mount_requests_tree(
+    requests: ProtoVolumeMountRequests,
+):
+    print("Mount Info:")
+    for request in requests.requests:
+        if request.mount_type == MOUNT_TYPE_ARCHIVE_FILE:
+            print(f"ㄴ {request.mount_path} -> (Uploaded)")
+        if request.mount_type == MOUNT_TYPE_CODE:
+            print(
+                f"ㄴ {request.mount_path} -> Code [{request.code.git_provider}@{request.code.git_owner}/{request.code.git_repo}@{request.code.git_ref}]"
+            )
+        if request.mount_type == MOUNT_TYPE_DATASET:
+            print(f"ㄴ {request.mount_path} -> Dataset [{request.dataset.dataset_name}]")
+        if request.mount_type == MOUNT_TYPE_DATASET_VERSION:
+            print(
+                f"ㄴ {request.mount_path} -> Dataset [{request.dataset_version.dataset_name}@{request.dataset_version.dataset_version_hash}]"
+            )
+        if request.mount_type == MOUNT_TYPE_MODEL_VOLUME:
+            print(
+                f"ㄴ {request.mount_path} -> Model [{request.model_volume.model_repository_name}/{request.model_volume.model_number}{request.model_volume.sub_path}]"
+            )
+        if request.mount_type == MOUNT_TYPE_OUTPUT:
+            print(f"ㄴ {request.mount_path} -> (output)")
 
 
 def _configure_volume_mount_requests(
     dataset_mounts: Optional[List[str]],
     git_ref_mounts: Optional[List[str]],
     git_diff_mount: Optional[str],
-    local_files: Optional[List[str]],
-    upload_local_git_diff: bool,
     archive_file_mount: Optional[str],
     root_volume_size: Optional[str],
     working_dir: Optional[str],
     output_dir: Optional[str],
+    model_mounts: Optional[List[str]] = None,
+    local_files: Optional[List[str]] = None,
+    upload_local_git_diff: bool = False,
     **kwargs,
 ) -> ProtoVolumeMountRequests:
     requests = [
@@ -247,15 +383,19 @@ def _configure_volume_mount_requests(
     ]
 
     if local_files:
-        requests.extend(_configure_volume_mount_request_local_files(local_files, **kwargs))
+        requests.extend(
+            _configure_volume_mount_request_local_files(local_files, **kwargs)
+        )
 
     if not git_ref_mounts and git_diff_mount is None and archive_file_mount is None:
         # No information for code mount is given - user is creating new experiment from CLI.
         # Generate VolumeMountRequest from projectRepository and local working directory
-        requests.extend(_configure_volume_mount_request_local_git(upload_local_git_diff, **kwargs))
+        requests.extend(
+            _configure_volume_mount_request_local_git(upload_local_git_diff, **kwargs)
+        )
     else:
         # Explicit information for code mount is given - user is reproducing experiment from CLI.
-        if not git_ref_mounts:
+        if git_ref_mounts:
             requests.extend(
                 _configure_volume_mount_request_codes(
                     git_ref_mounts, git_diff_mount, **kwargs
@@ -269,67 +409,120 @@ def _configure_volume_mount_requests(
             )
 
     if dataset_mounts is not None:
+        requests.extend(
+            _configure_volume_mount_request_datasets(dataset_mounts, **kwargs)
+        )
+
+    if model_mounts is not None:
         requests += [
-            _configure_volume_mount_request_dataset(dataset_mount, **kwargs)
-            for dataset_mount in dataset_mounts
+            _configure_volume_mount_request_model(model_mount, **kwargs)
+            for model_mount in model_mounts
         ]
 
-    return ProtoVolumeMountRequests(
+    requests = ProtoVolumeMountRequests(
         root_volume_size=root_volume_size,
         working_dir=working_dir,
         requests=requests,
     )
+    _print_volume_mount_requests_tree(requests)
+    return requests
 
 
-def _configure_volume_mount_request_dataset(
-    dataset_mount: str, **kwargs
-) -> ProtoVolumeMountRequest:
+def _configure_volume_mount_request_datasets(
+    dataset_mounts: List[str], should_add_project_datasets=True, **kwargs
+) -> List[ProtoVolumeMountRequest]:
     from vessl.dataset import read_dataset, read_dataset_version
 
-    mount_path, dataset_path = dataset_mount.split(":", 1)
+    dataset_mount_map: Dict[int, ProtoVolumeMountRequest] = {}
+    if should_add_project_datasets:
+        project = _get_project(**kwargs)
+        for project_dataset in project.project_datasets:
+            mount_path = project_dataset.mount_path
+            dataset = project_dataset.dataset
+
+            dataset_mount_map[dataset.id] = ProtoVolumeMountRequest(
+                mount_type=MOUNT_TYPE_DATASET,
+                mount_path=mount_path,
+                dataset=ProtoVolumeMountRequestSourceDataset(
+                    dataset_id=dataset.id,
+                    dataset_name=dataset.name,
+                ),
+            )
+
+    for dataset_mount in dataset_mounts:
+        mount_path, dataset_path = dataset_mount.split(":", 1)
+        mount_path = os.path.join(mount_path, "")  # Ensure path ends in /
+
+        organization_name = _get_organization_name(**kwargs)
+        dataset_name = dataset_path
+        dataset_version_hash = DATASET_VERSION_HASH_LATEST
+
+        if "@" in dataset_path:
+            # Example: mnist@3d1e0f91c
+            dataset_name, dataset_version_hash = dataset_path.rsplit("@", 1)
+
+        if "/" in dataset_name:
+            # Example: org1/mnist@3d1e0f91c
+            organization_name, dataset_name = dataset_name.split("/", 1)
+
+        dataset = read_dataset(dataset_name, organization_name=organization_name)
+
+        if not dataset.is_version_enabled:
+            dataset_mount_map[dataset.id] = ProtoVolumeMountRequest(
+                mount_type=MOUNT_TYPE_DATASET,
+                mount_path=mount_path,
+                dataset=ProtoVolumeMountRequestSourceDataset(
+                    dataset_id=dataset.id,
+                    dataset_name=dataset_name,
+                ),
+            )
+
+        if dataset_version_hash != DATASET_VERSION_HASH_LATEST:
+            dataset_version_hash = read_dataset_version(
+                dataset.id, dataset_version_hash
+            ).version_hash  # Get full version hash from truncated one given by input
+
+            dataset_mount_map[dataset.id] = ProtoVolumeMountRequest(
+                mount_type=MOUNT_TYPE_DATASET_VERSION,
+                mount_path=mount_path,
+                dataset_version=ProtoVolumeMountRequestSourceDatasetVersion(
+                    dataset_id=dataset.id,
+                    dataset_name=dataset_name,
+                    dataset_version_hash=dataset_version_hash,
+                ),
+            )
+
+    return list(dataset_mount_map.values())
+
+
+def _configure_volume_mount_request_model(
+    model_mount: str, **kwargs
+) -> ProtoVolumeMountRequest:
+    from vessl.model import read_model
+
+    mount_path, model_path = model_mount.split(":", 1)
+    model_repository_name, model_number = model_path.split("/", 1)
+
     mount_path = os.path.join(mount_path, "")  # Ensure path ends in /
 
-    organization_name = _get_organization_name(**kwargs)
-    dataset_name = dataset_path
-    dataset_version_hash = DATASET_VERSION_HASH_LATEST
-
-    if "@" in dataset_path:
-        # Example: mnist@3d1e0f91c
-        dataset_name, dataset_version_hash = dataset_path.rsplit("@", 1)
-
-    if "/" in dataset_name:
-        # Example: org1/mnist@3d1e0f91c
-        organization_name, dataset_name = dataset_name.split("/", 1)
-
-    dataset = read_dataset(dataset_name, organization_name=organization_name)
-
-    if not dataset.is_version_enabled:
-        return ProtoVolumeMountRequest(
-            mount_type=MOUNT_TYPE_DATASET,
-            mount_path=mount_path,
-            dataset=ProtoVolumeMountRequestSourceDataset(
-                dataset_id=dataset.id,
-                dataset_name=dataset_name,
-            ),
-        )
-
-    if dataset_version_hash != DATASET_VERSION_HASH_LATEST:
-        dataset_version_hash = read_dataset_version(
-            dataset.id, dataset_version_hash
-        ).version_hash  # Get full version hash from truncated one given by input
+    model = read_model(
+        repository_name=model_repository_name, model_number=model_number, **kwargs
+    )
 
     return ProtoVolumeMountRequest(
-        mount_type=MOUNT_TYPE_DATASET_VERSION,
+        mount_type=MOUNT_TYPE_MODEL_VOLUME,
         mount_path=mount_path,
-        dataset_version=ProtoVolumeMountRequestSourceDatasetVersion(
-            dataset_id=dataset.id,
-            dataset_name=dataset_name,
-            dataset_version_hash=dataset_version_hash,
+        model_volume=ProtoVolumeMountRequestSourceModelVolume(
+            sub_path="/",
+            model_repository_name=model.model_repository.name,
+            model_number=model.number,
         ),
     )
 
 
-def _configure_volume_mount_request_local_files(local_files: List[str], **kwargs) -> List[ProtoVolumeMountRequest]:
+def _configure_volume_mount_request_local_files(
+    local_files: List[str], **kwargs
+) -> List[ProtoVolumeMountRequest]:
     project = _get_project(**kwargs)
 
     volume_mount_requests: List[ProtoVolumeMountRequest] = []
@@ -346,6 +539,8 @@ def _configure_volume_mount_request_local_files(local_files: List[str], **kwargs
         zip_path = os.path.abspath(
             os.path.join(tempfile.gettempdir(), f"{project.name}_{random_string()}.zip")
         )
+
+        print(f"Uploading... [{cwd} -> {remote_path}]")
         zipper = Zipper(zip_path, "w")
         zipper.zip(cwd)
         zipper.close()
@@ -355,6 +550,8 @@ def _configure_volume_mount_request_local_files(local_files: List[str], **kwargs
             volume_id=project.volume_id,
             remote_path=os.path.basename(zipper.filename),
         )
+        print(f"Upload completed successfully.")
+
         os.remove(zipper.filename)
         volume_mount_requests.append(
             _configure_volume_mount_request_archive_file(
@@ -365,7 +562,9 @@ def _configure_volume_mount_request_local_files(local_files: List[str], **kwargs
     return volume_mount_requests
 
 
-def _configure_volume_mount_request_local_git(upload_local_git_diff, **kwargs) -> List[ProtoVolumeMountRequest]:
+def _configure_volume_mount_request_local_git(
+    upload_local_git_diff, **kwargs
+) -> List[ProtoVolumeMountRequest]:
     project = _get_project(**kwargs)
 
     local_git_owner, local_git_repo = None, None
@@ -383,7 +582,11 @@ def _configure_volume_mount_request_local_git(upload_local_git_diff, **kwargs) -
 
         git_mount_info = f"github/{repo.git_owner}/{repo.git_repo}/latest"
         git_diff_path = None
-        if upload_local_git_diff and repo.git_owner == local_git_owner and repo.git_repo == local_git_repo:
+        if (
+            upload_local_git_diff
+            and repo.git_owner == local_git_owner
+            and repo.git_repo == local_git_repo
+        ):
             # Current working directory is one of the project repository.
             # Mount VolumeSourceCode with potential uncommitted changes
             git_diff_path = get_git_diff_path(project)
